# -*- coding: utf-8 -*-

__author__ = 'wong2'
__email__ = 'wonderfuly@gmail.com'
__version__ = '0.2.0'
SERVER_SOFTWARE = 'Larus/%s' % __version__
